aboutsummaryrefslogtreecommitdiffstats
path: root/oni-elisp/oni-elisp.el
diff options
context:
space:
mode:
authorGravatar Tom Willemse2020-03-06 23:14:50 -0800
committerGravatar Tom Willemse2020-03-06 23:14:50 -0800
commit4d272ffb4abced360622418c576023fc421694e1 (patch)
tree65e301bf4071131e614f671ae854fc67289a96d7 /oni-elisp/oni-elisp.el
parent19ffa2888e6c2f9fb35cee1a1f61c8a659868e44 (diff)
downloademacs-config-4d272ffb4abced360622418c576023fc421694e1.tar.gz
emacs-config-4d272ffb4abced360622418c576023fc421694e1.zip
Add hydra for emacs-lisp
Diffstat (limited to 'oni-elisp/oni-elisp.el')
-rw-r--r--oni-elisp/oni-elisp.el13
1 files changed, 11 insertions, 2 deletions
diff --git a/oni-elisp/oni-elisp.el b/oni-elisp/oni-elisp.el
index 8f6da22..6260479 100644
--- a/oni-elisp/oni-elisp.el
+++ b/oni-elisp/oni-elisp.el
@@ -4,8 +4,8 @@
;; Author: Tom Willemse <tom@ryuslash.org>
;; Keywords: local
;; Version: 2020.0229.130740
;; Package-Requires: (oni-company oni-flycheck oni-paredit oni-fci oni-yasnippet rainbow-delimiters nameless erefactor flycheck-relint)
;; This program is free software; you can redistribute it and/or modify
;; it under the terms of the GNU General Public License as published by
@@ -56,6 +56,14 @@
(setq-local comment-auto-fill-only-comments t)
(auto-fill-mode))
+(defhydra oni-elisp-hydra (:color teal :hint nil)
+ "
+^Eval^
+^^----------
+_eb_: Buffer
+"
+ ("eb" eval-buffer))
+
(add-hook 'emacs-lisp-mode-hook 'company-mode)
(add-hook 'emacs-lisp-mode-hook 'electric-quote-local-mode)
(add-hook 'emacs-lisp-mode-hook 'erefactor-lazy-highlight-turn-on)
@@ -72,6 +80,7 @@
(setq ielm-prompt "λ> ")
(define-key emacs-lisp-mode-map (kbd "C-c r") erefactor-map)
+(define-key emacs-lisp-mode-map (kbd "C-c SPC") 'oni-elisp-hydra/body)
;;;###autoload
(add-to-list 'auto-mode-alist '("/Cask\\'" . emacs-lisp-mode))
@@ -4,8 +4,8 @@
;; Author: Tom Willemse <tom@ryuslash.org>
;; Keywords: local
-;; Version: 2020.0229.130740
-;; Package-Requires: (oni-company oni-flycheck oni-paredit oni-fci oni-yasnippet rainbow-delimiters nameless erefactor flycheck-relint)
+;; Version: 2020.0306.231405
+;; Package-Requires: (oni-company oni-flycheck oni-paredit oni-fci oni-yasnippet oni-hydra rainbow-delimiters nameless erefactor flycheck-relint)
;; This program is free software; you can redistribute it and/or modify
;; it under the terms of the GNU General Public License as published by